VCF object with variant calls from an array of q-values.VCF object as output.
qvals2Vcf(qvals, counts, regions, samples = 1:nrow(counts), err = NULL, mu = NULL, cutoff = 0.05, mvcf = TRUE)betabinLRT.loadAllData.GRanges with the regions corresponding to counts and qvals.VCF object